<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Dotclear has been upgraded.'] = '';
$GLOBALS['__l10n']['Password reset'] = '';
$GLOBALS['__l10n']['Someone has requested to reset the password for the following site and username.'] = '';
$GLOBALS['__l10n']['Username:'] = '';
$GLOBALS['__l10n']['To reset your password visit the following address, otherwise just ignore this email and nothing will happen.'] = '';
$GLOBALS['__l10n']['The e-mail was sent successfully to %s.'] = '';
$GLOBALS['__l10n']['Your new password'] = '';
$GLOBALS['__l10n']['Password:'] = '';
$GLOBALS['__l10n']['Your new password is in your mailbox.'] = '';
$GLOBALS['__l10n']['Passwords don\'t match'] = '';
$GLOBALS['__l10n']['You didn\'t change your password.'] = '';
$GLOBALS['__l10n']['You have to change your password before you can login.'] = '';
$GLOBALS['__l10n']['In order to login, you have to change your password now.'] = '';
$GLOBALS['__l10n']['Safe Mode can only be used for super administrators.'] = '';
$GLOBALS['__l10n']['Insufficient permissions'] = '';
$GLOBALS['__l10n']['Wrong username or password'] = '';
$GLOBALS['__l10n']['Back to login screen'] = '';
$GLOBALS['__l10n']['Request a new password'] = '';
$GLOBALS['__l10n']['Email:'] = '';
$GLOBALS['__l10n']['recover'] = '';
$GLOBALS['__l10n']['Change your password'] = '';
$GLOBALS['__l10n']['New password:'] = '';
$GLOBALS['__l10n']['Confirm password:'] = '';
$GLOBALS['__l10n']['change'] = '';
$GLOBALS['__l10n']['Safe mode login'] = '';
$GLOBALS['__l10n']['This mode allows you to login without activating any of your plugins. This may be useful to solve compatibility problems'] = '';
$GLOBALS['__l10n']['Disable or delete any plugin suspected to cause trouble, then log out and log back in normally.'] = '';
$GLOBALS['__l10n']['Remember my ID on this computer'] = '';
$GLOBALS['__l10n']['log in'] = '';
$GLOBALS['__l10n']['You must accept cookies in order to use the private area.'] = '';
$GLOBALS['__l10n']['Get back to normal authentication'] = '';
$GLOBALS['__l10n']['Connection issue?'] = '';
$GLOBALS['__l10n']['I forgot my password'] = '';
$GLOBALS['__l10n']['I want to log in in safe mode'] = '';
$GLOBALS['__l10n']['Blog "%s" successfully created'] = '';
$GLOBALS['__l10n']['New blog'] = '';
$GLOBALS['__l10n']['System'] = '';
$GLOBALS['__l10n']['Blogs'] = '';
$GLOBALS['__l10n']['Blog ID:'] = '';
$GLOBALS['__l10n']['Required field'] = '';
$GLOBALS['__l10n']['At least 2 characters using letters, numbers or symbols.'] = '';
$GLOBALS['__l10n']['Blog name:'] = '';
$GLOBALS['__l10n']['Blog URL:'] = '';
$GLOBALS['__l10n']['Blog description:'] = '';
$GLOBALS['__l10n']['Create'] = '';
$GLOBALS['__l10n']['No such blog ID'] = '';
$GLOBALS['__l10n']['Password verification failed'] = '';
$GLOBALS['__l10n']['Blog "%s" successfully deleted'] = '';
$GLOBALS['__l10n']['Delete a blog'] = '';
$GLOBALS['__l10n']['Warning'] = '';
$GLOBALS['__l10n']['You are about to delete the blog %s. Every entry, comment and category will be deleted.'] = '';
$GLOBALS['__l10n']['Please give your password to confirm the blog deletion.'] = '';
$GLOBALS['__l10n']['Your password:'] = '';
$GLOBALS['__l10n']['Delete this blog'] = '';
$GLOBALS['__l10n']['No given blog id.'] = '';
$GLOBALS['__l10n']['No such blog.'] = '';
$GLOBALS['__l10n']['year/month/day/title'] = '';
$GLOBALS['__l10n']['year/month/title'] = '';
$GLOBALS['__l10n']['year/title'] = '';
$GLOBALS['__l10n']['title'] = '';
$GLOBALS['__l10n']['post id/title'] = '';
$GLOBALS['__l10n']['post id'] = '';
$GLOBALS['__l10n']['H4'] = '';
$GLOBALS['__l10n']['H3'] = '';
$GLOBALS['__l10n']['P'] = '';
$GLOBALS['__l10n']['(none)'] = '';
$GLOBALS['__l10n']['Title'] = '';
$GLOBALS['__l10n']['Title, Date'] = '';
$GLOBALS['__l10n']['Title, Country, Date'] = '';
$GLOBALS['__l10n']['Title, City, Country, Date'] = '';
$GLOBALS['__l10n']['original'] = '';
$GLOBALS['__l10n']['None'] = '';
$GLOBALS['__l10n']['Left'] = '';
$GLOBALS['__l10n']['Right'] = '';
$GLOBALS['__l10n']['Center'] = '';
$GLOBALS['__l10n']['I would like search engines and archivers to index and archive my blog\'s content.'] = '';
$GLOBALS['__l10n']['I would like search engines and archivers to index but not archive my blog\'s content.'] = '';
$GLOBALS['__l10n']['I would like to prevent search engines and archivers from indexing or archiving my blog\'s content.'] = '';
$GLOBALS['__l10n']['Default'] = '';
$GLOBALS['__l10n']['This blog ID is already used.'] = '';
$GLOBALS['__l10n']['Invalid language code'] = '';
$GLOBALS['__l10n']['Blog has been successfully updated.'] = '';
$GLOBALS['__l10n']['Blog settings'] = '';
$GLOBALS['__l10n']['Warning: except for special configurations, it is generally advised to have a trailing "/" in your blog URL in PATH_INFO mode.'] = '';
$GLOBALS['__l10n']['Warning: except for special configurations, it is generally advised to have a trailing "?" in your blog URL in QUERY_STRING mode.'] = '';
$GLOBALS['__l10n']['Blog has been successfully created.'] = '';
$GLOBALS['__l10n']['Parameters'] = '';
$GLOBALS['__l10n']['Blog details'] = '';
$GLOBALS['__l10n']['Please note that changing your blog ID may require changes in your public index.php file.'] = '';
$GLOBALS['__l10n']['URL scan method:'] = '';
$GLOBALS['__l10n']['The URL of blog or the URL scan method might not be well set (<code>%s</code> return a <strong>%s</strong> status).'] = '';
$GLOBALS['__l10n']['The URL of blog or the URL scan method might not be well set (<code>%s</code> does not return an ATOM feed).'] = '';
$GLOBALS['__l10n']['Blog status:'] = '';
$GLOBALS['__l10n']['Blog configuration'] = '';
$GLOBALS['__l10n']['Blog editor name:'] = '';
$GLOBALS['__l10n']['Default language:'] = '';
$GLOBALS['__l10n']['Blog timezone:'] = '';
$GLOBALS['__l10n']['Copyright notice:'] = '';
$GLOBALS['__l10n']['New post URL format:'] = '';
$GLOBALS['__l10n']['HTML tag for the title of the notes on the blog:'] = '';
$GLOBALS['__l10n']['Enable XML/RPC interface'] = '';
$GLOBALS['__l10n']['XML/RPC interface allows you to edit your blog with an external client.'] = '';
$GLOBALS['__l10n']['XML/RPC interface is active. You should set the following parameters on your XML/RPC client:'] = '';
$GLOBALS['__l10n']['Server URL:'] = '';
$GLOBALS['__l10n']['Blogging system:'] = '';
$GLOBALS['__l10n']['User name:'] = '';
$GLOBALS['__l10n']['your password'] = '';
$GLOBALS['__l10n']['Comments and trackbacks'] = '';
$GLOBALS['__l10n']['Accept comments'] = '';
$GLOBALS['__l10n']['Moderate comments'] = '';
$GLOBALS['__l10n']['Leave comments open for %s days'] = '';
$GLOBALS['__l10n']['No limit: leave blank.'] = '';
$GLOBALS['__l10n']['Wiki syntax for comments'] = '';
$GLOBALS['__l10n']['Preview of comment before submit is not mandatory'] = '';
$GLOBALS['__l10n']['Accept trackbacks'] = '';
$GLOBALS['__l10n']['Moderate trackbacks'] = '';
$GLOBALS['__l10n']['Leave trackbacks open for %s days'] = '';
$GLOBALS['__l10n']['Add "nofollow" relation on comments and trackbacks links'] = '';
$GLOBALS['__l10n']['Blog presentation'] = '';
$GLOBALS['__l10n']['Date format:'] = '';
$GLOBALS['__l10n']['Pattern of date'] = '';
$GLOBALS['__l10n']['Sample:'] = '';
$GLOBALS['__l10n']['Time format:'] = '';
$GLOBALS['__l10n']['Pattern of time'] = '';
$GLOBALS['__l10n']['Display smilies on entries and comments'] = '';
$GLOBALS['__l10n']['Display %s entries on home page'] = '';
$GLOBALS['__l10n']['Display %s entries per page'] = '';
$GLOBALS['__l10n']['Display %s entries per feed'] = '';
$GLOBALS['__l10n']['Display %s comments per feed'] = '';
$GLOBALS['__l10n']['Truncate feeds'] = '';
$GLOBALS['__l10n']['Include sub-categories in category page and category posts feed'] = '';
$GLOBALS['__l10n']['Media and images'] = '';
$GLOBALS['__l10n']['Please note that if you change current settings bellow, they will now apply to all new images in the media manager.'] = '';
$GLOBALS['__l10n']['Be carefull if you share it with other blogs in your installation.'] = '';
$GLOBALS['__l10n']['Generated image sizes (in pixels)'] = '';
$GLOBALS['__l10n']['Default image insertion attributes'] = '';
$GLOBALS['__l10n']['Inserted image title'] = '';
$GLOBALS['__l10n']['Use original media date if possible'] = '';
$GLOBALS['__l10n']['Do not display date if alone in title'] = '';
$GLOBALS['__l10n']['It is retrieved from the picture\'s metadata.'] = '';
$GLOBALS['__l10n']['Size of inserted image:'] = '';
$GLOBALS['__l10n']['Image alignment:'] = '';
$GLOBALS['__l10n']['Insert a link to the original image'] = '';
$GLOBALS['__l10n']['Search engines robots policy'] = '';
$GLOBALS['__l10n']['jQuery javascript library'] = '';
$GLOBALS['__l10n']['jQuery version to be loaded for this blog:'] = '';
$GLOBALS['__l10n']['Blog security'] = '';
$GLOBALS['__l10n']['Protect the blog from Clickjacking (see <a href="https://en.wikipedia.org/wiki/Clickjacking">Wikipedia</a>)'] = '';
$GLOBALS['__l10n']['Save'] = '';
$GLOBALS['__l10n']['The current blog cannot be deleted.'] = '';
$GLOBALS['__l10n']['Only superadmin can delete a blog.'] = '';
$GLOBALS['__l10n']['Users'] = '';
$GLOBALS['__l10n']['Users on this blog'] = '';
$GLOBALS['__l10n']['No users'] = '';
$GLOBALS['__l10n']['Publications on this blog:'] = '';
$GLOBALS['__l10n']['%1$s: %2$s'] = '';
$GLOBALS['__l10n']['Permissions:'] = '';
$GLOBALS['__l10n']['Super administrator'] = '';
$GLOBALS['__l10n']['All rights on all blogs.'] = '';
$GLOBALS['__l10n']['[%s] (unreferenced permission)'] = '';
$GLOBALS['__l10n']['All rights on this blog.'] = '';
$GLOBALS['__l10n']['Change permissions'] = '';
$GLOBALS['__l10n']['Blog appearance'] = '';
$GLOBALS['__l10n']['Theme configuration'] = '';
$GLOBALS['__l10n']['Themes management'] = '';
$GLOBALS['__l10n']['Update themes'] = '';
$GLOBALS['__l10n']['There is one theme to update available from repository.'][0] = '';
$GLOBALS['__l10n']['There is one theme to update available from repository.'][1] = '';
$GLOBALS['__l10n']['Visit %s repository, the resources center for Dotclear.'] = '';
$GLOBALS['__l10n']['Installed themes'] = '';
$GLOBALS['__l10n']['You can configure and manage installed themes from this list.'] = '';
$GLOBALS['__l10n']['Deactivated themes'] = '';
$GLOBALS['__l10n']['Deactivated themes are installed but not usable. You can activate them from here.'] = '';
$GLOBALS['__l10n']['Add themes'] = '';
$GLOBALS['__l10n']['Add themes from repository'] = '';
$GLOBALS['__l10n']['Install or upgrade manually'] = '';
$GLOBALS['__l10n']['Add themes from a package'] = '';
$GLOBALS['__l10n']['You can install themes by uploading or downloading zip files.'] = '';
$GLOBALS['__l10n']['Last update'] = '';
$GLOBALS['__l10n']['Blog name'] = '';
$GLOBALS['__l10n']['Blog ID'] = '';
$GLOBALS['__l10n']['Descending'] = '';
$GLOBALS['__l10n']['Ascending'] = '';
$GLOBALS['__l10n']['Show filters and display options'] = '';
$GLOBALS['__l10n']['Cancel filters and display options'] = '';
$GLOBALS['__l10n']['List of blogs'] = '';
$GLOBALS['__l10n']['Blog has been successfully deleted.'] = '';
$GLOBALS['__l10n']['Create a new blog'] = '';
$GLOBALS['__l10n']['Filter blogs list'] = '';
$GLOBALS['__l10n']['Filters'] = '';
$GLOBALS['__l10n']['Search:'] = '';
$GLOBALS['__l10n']['Display options'] = '';
$GLOBALS['__l10n']['Order by:'] = '';
$GLOBALS['__l10n']['Sort:'] = '';
$GLOBALS['__l10n']['Show'] = '';
$GLOBALS['__l10n']['blogs per page'] = '';
$GLOBALS['__l10n']['Apply filters and display options'] = '';
$GLOBALS['__l10n']['No blog matches the filter'] = '';
$GLOBALS['__l10n']['No blog'] = '';
$GLOBALS['__l10n']['%d blog matches the filter.'][0] = '';
$GLOBALS['__l10n']['%d blog matches the filter.'][1] = '';
$GLOBALS['__l10n']['Blogs list'] = '';
$GLOBALS['__l10n']['Blog id'] = '';
$GLOBALS['__l10n']['Entries (all types)'] = 'Entries';
$GLOBALS['__l10n']['Status'] = '';
$GLOBALS['__l10n']['Edit blog settings for %s'] = '';
$GLOBALS['__l10n']['Edit blog settings'] = '';
$GLOBALS['__l10n']['Switch to blog %s'] = '';
$GLOBALS['__l10n']['This category does not exist.'] = '';
$GLOBALS['__l10n']['The category "%s" has been successfully deleted.'] = '';
$GLOBALS['__l10n']['Category where to move posts does not exist'] = '';
$GLOBALS['__l10n']['The entries have been successfully moved to category "%s"'] = '';
$GLOBALS['__l10n']['Categories have been successfully reordered.'] = '';
$GLOBALS['__l10n']['Categories order has been successfully reset.'] = '';
$GLOBALS['__l10n']['Categories'] = '';
$GLOBALS['__l10n']['The category has been successfully removed.'][0] = '';
$GLOBALS['__l10n']['The category has been successfully removed.'][1] = '';
$GLOBALS['__l10n']['Entries have been successfully moved to the category you choose.'] = '';
$GLOBALS['__l10n']['New category'] = '';
$GLOBALS['__l10n']['No category so far.'] = '';
$GLOBALS['__l10n']['%d entries'] = '';
$GLOBALS['__l10n']['%d entry'][0] = '';
$GLOBALS['__l10n']['%d entry'][1] = '';
$GLOBALS['__l10n']['total:'] = '';
$GLOBALS['__l10n']['URL:'] = '';
$GLOBALS['__l10n']['Move entries to'] = '';
$GLOBALS['__l10n']['OK'] = '';
$GLOBALS['__l10n']['Delete category'] = '';
$GLOBALS['__l10n']['To rearrange categories order, move items by drag and drop, then click on “Save categories order” button.'] = '';
$GLOBALS['__l10n']['Save categories order'] = '';
$GLOBALS['__l10n']['Reorder all categories on the top level'] = '';
$GLOBALS['__l10n']['Top level'] = '';
$GLOBALS['__l10n']['The category has been successfully moved'] = '';
$GLOBALS['__l10n']['The category has been successfully updated.'] = '';
$GLOBALS['__l10n']['The category "%s" has been successfully created.'] = '';
$GLOBALS['__l10n']['Category has been successfully updated.'] = '';
$GLOBALS['__l10n']['Category information'] = '';
$GLOBALS['__l10n']['Name:'] = '';
$GLOBALS['__l10n']['Parent:'] = '';
$GLOBALS['__l10n']['Warning: If you set the URL manually, it may conflict with another category.'] = '';
$GLOBALS['__l10n']['Description:'] = '';
$GLOBALS['__l10n']['Move this category'] = '';
$GLOBALS['__l10n']['Category parent'] = '';
$GLOBALS['__l10n']['Category sibling'] = '';
$GLOBALS['__l10n']['Move current category'] = '';
$GLOBALS['__l10n']['after'] = '';
$GLOBALS['__l10n']['before'] = '';
$GLOBALS['__l10n']['position: '] = '';
$GLOBALS['__l10n']['Entry does not exist.'] = '';
$GLOBALS['__l10n']['Comment has been successfully created.'] = '';
$GLOBALS['__l10n']['No comments'] = '';
$GLOBALS['__l10n']['Comment has been successfully updated.'] = '';
$GLOBALS['__l10n']['Comment has been successfully deleted.'] = '';
$GLOBALS['__l10n']['You can\'t edit this comment.'] = '';
$GLOBALS['__l10n']['Edit comment'] = '';
$GLOBALS['__l10n']['Your comment on my blog %s'] = '';
$GLOBALS['__l10n']['Hi!

You wrote a comment on:
%s


'] = '';
$GLOBALS['__l10n']['Send an e-mail'] = '';
$GLOBALS['__l10n']['Information collected'] = '';
$GLOBALS['__l10n']['IP address:'] = '';
$GLOBALS['__l10n']['Date:'] = '';
$GLOBALS['__l10n']['Comment submitted'] = '';
$GLOBALS['__l10n']['Author:'] = '';
$GLOBALS['__l10n']['Web site:'] = '';
$GLOBALS['__l10n']['Status:'] = '';
$GLOBALS['__l10n']['Comment:'] = '';
$GLOBALS['__l10n']['Delete'] = '';
$GLOBALS['__l10n']['Comment'] = '';
$GLOBALS['__l10n']['Trackback'] = '';
$GLOBALS['__l10n']['Date'] = '';
$GLOBALS['__l10n']['Entry title'] = '';
$GLOBALS['__l10n']['Author'] = '';
$GLOBALS['__l10n']['Selected comments have been successfully updated.'] = '';
$GLOBALS['__l10n']['Selected comments have been successfully deleted.'] = '';
$GLOBALS['__l10n']['Spam comments have been successfully deleted.'] = '';
$GLOBALS['__l10n']['You have one spam comment.'] = '';
$GLOBALS['__l10n']['Show it.'] = '';
$GLOBALS['__l10n']['You have %s spam comments.'] = '';
$GLOBALS['__l10n']['Show them.'] = '';
$GLOBALS['__l10n']['Delete all spams'] = '';
$GLOBALS['__l10n']['Filter comments and trackbacks list'] = '';
$GLOBALS['__l10n']['Type:'] = '';
$GLOBALS['__l10n']['comments per page'] = '';
$GLOBALS['__l10n']['Selected comments action:'] = '';
$GLOBALS['__l10n']['Actions'] = '';
$GLOBALS['__l10n']['ok'] = '';
$GLOBALS['__l10n']['Global help'] = '';
$GLOBALS['__l10n']['An update is available'][0] = '';
$GLOBALS['__l10n']['An update is available'][1] = '';
$GLOBALS['__l10n']['Dotclear news'] = '';
$GLOBALS['__l10n']['%d %B %Y:'] = '';
$GLOBALS['__l10n']['Documentation and support'] = '';
$GLOBALS['__l10n']['Dashboard'] = '';
$GLOBALS['__l10n']['Dotclear %s is available!'] = '';
$GLOBALS['__l10n']['Upgrade now'] = '';
$GLOBALS['__l10n']['Remind me later'] = '';
$GLOBALS['__l10n']['Information about this version'] = '';
$GLOBALS['__l10n']['Make this blog my default blog'] = '';
$GLOBALS['__l10n']['This blog is offline'] = '';
$GLOBALS['__l10n']['This blog is removed'] = '';
$GLOBALS['__l10n']['%s is not defined, you should edit your configuration file.'] = '';
$GLOBALS['__l10n']['See <a href="http://dotclear.org/documentation/2.0/admin/config">documentation</a> for more information.'] = '';
$GLOBALS['__l10n']['The cache directory does not exist or is not writable. You must create this directory with sufficient rights and affect this location to "DC_TPL_CACHE" in inc/config.php file.'] = '';
$GLOBALS['__l10n']['The cache directory does not exist or is not writable. You should contact your administrator.'] = '';
$GLOBALS['__l10n']['There is no writable directory /public/ at the location set in about:config "public_path". You must create this directory with sufficient rights (or change this setting).'] = '';
$GLOBALS['__l10n']['There is no writable root directory for the media manager. You should contact your administrator.'] = '';
$GLOBALS['__l10n']['Error:'] = '';
$GLOBALS['__l10n']['Following plugins have been installed:'] = '';
$GLOBALS['__l10n']['Following plugins have not been installed:'] = '';
$GLOBALS['__l10n']['Errors have occured with following plugins:'] = '';
$GLOBALS['__l10n']['Quick entry'] = '';
$GLOBALS['__l10n']['New entry'] = '';
$GLOBALS['__l10n']['Title:'] = '';
$GLOBALS['__l10n']['Content:'] = '';
$GLOBALS['__l10n']['Category:'] = '';
$GLOBALS['__l10n']['Add a new category'] = '';
$GLOBALS['__l10n']['This category will be created when you will save your post.'] = '';
$GLOBALS['__l10n']['Save and publish'] = '';
$GLOBALS['__l10n']['PHP version is %s (5.0 or earlier needed).'] = '';
$GLOBALS['__l10n']['Multibyte string module (mbstring) is not available.'] = '';
$GLOBALS['__l10n']['Iconv module is not available.'] = '';
$GLOBALS['__l10n']['Output control functions are not available.'] = '';
$GLOBALS['__l10n']['SimpleXML module is not available.'] = '';
$GLOBALS['__l10n']['DOM XML module is not available.'] = '';
$GLOBALS['__l10n']['PCRE engine does not support UTF-8 strings.'] = '';
$GLOBALS['__l10n']['SPL module is not available.'] = '';
$GLOBALS['__l10n']['MySQL version is %s (4.1 or earlier needed).'] = '';
$GLOBALS['__l10n']['MySQL InnoDB engine is not available.'] = '';
$GLOBALS['__l10n']['PostgreSQL version is %s (8.0 or earlier needed).'] = '';
$GLOBALS['__l10n']['Please set a master key (DC_MASTER_KEY) in configuration file.'] = '';
$GLOBALS['__l10n']['Dotclear is already installed.'] = '';
$GLOBALS['__l10n']['Dotclear cannot be installed.'] = '';
$GLOBALS['__l10n']['No user ID given'] = '';
$GLOBALS['__l10n']['User ID must contain at least 2 characters using letters, numbers or symbols.'] = '';
$GLOBALS['__l10n']['Invalid email address'] = '';
$GLOBALS['__l10n']['No password given'] = '';
$GLOBALS['__l10n']['Password must contain at least 6 characters.'] = '';
$GLOBALS['__l10n']['My first blog'] = '';
$GLOBALS['__l10n']['%A, %B %e %Y'] = '';
$GLOBALS['__l10n']['Welcome to Dotclear!'] = '';
$GLOBALS['__l10n']['This is your first entry. When you\'re ready to blog, log in to edit or delete it.'] = '';
$GLOBALS['__l10n']['Dotclear Team'] = '';
$GLOBALS['__l10n']['<p>This is a comment.</p>
<p>To delete it, log in and view your blog\'s comments. Then you might remove or edit it.</p>'] = '';
$GLOBALS['__l10n']['Dotclear Install'] = '';
$GLOBALS['__l10n']['Password strength: %s'] = '';
$GLOBALS['__l10n']['very weak'] = '';
$GLOBALS['__l10n']['weak'] = '';
$GLOBALS['__l10n']['mediocre'] = '';
$GLOBALS['__l10n']['strong'] = '';
$GLOBALS['__l10n']['very strong'] = '';
$GLOBALS['__l10n']['show'] = '';
$GLOBALS['__l10n']['Dotclear installation'] = '';
$GLOBALS['__l10n']['Cache directory %s is not writable.'] = '';
$GLOBALS['__l10n']['Errors:'] = '';
$GLOBALS['__l10n']['Configuration file has been successfully created.'] = '';
$GLOBALS['__l10n']['User information'] = '';
$GLOBALS['__l10n']['Please provide the following information needed to create the first user.'] = '';
$GLOBALS['__l10n']['First Name:'] = '';
$GLOBALS['__l10n']['Last Name:'] = '';
$GLOBALS['__l10n']['Username and password'] = '';
$GLOBALS['__l10n']['All done!'] = '';
$GLOBALS['__l10n']['Dotclear has been successfully installed. Here is some useful information you should keep.'] = '';
$GLOBALS['__l10n']['Your account'] = '';
$GLOBALS['__l10n']['Your blog'] = '';
$GLOBALS['__l10n']['Blog address:'] = '';
$GLOBALS['__l10n']['Administration interface:'] = '';
$GLOBALS['__l10n']['Manage your blog now'] = '';
$GLOBALS['__l10n']['Installation can not be completed'] = '';
$GLOBALS['__l10n']['For the said reasons, Dotclear can not be installed. Please refer to <a href="http://dotclear.org/documentation/2.0/admin/install">the documentation</a> to learn how to correct the problem.'] = '';
$GLOBALS['__l10n']['Path <strong>%s</strong> is not writable.'] = '';
$GLOBALS['__l10n']['Dotclear installation wizard could not create configuration file for you. You must change folder right or create the <strong>config.php</strong> file manually, please refer to <a href="http://dotclear.org/documentation/2.0/admin/install">the documentation</a> to learn how to do this.'] = '';
$GLOBALS['__l10n']['File %s does not exist.'] = '';
$GLOBALS['__l10n']['Cannot write %s file.'] = '';
$GLOBALS['__l10n']['Dotclear installation wizard'] = '';
$GLOBALS['__l10n']['Welcome'] = '';
$GLOBALS['__l10n']['To complete your Dotclear installation and start writing on your blog, we just need to know how to access your database and who you are. Just fill this two steps wizard with this information and we will be done.'] = '';
$GLOBALS['__l10n']['Attention:'] = '';
$GLOBALS['__l10n']['this wizard may not function on every host. If it does not work for you, please refer to <a href="http://dotclear.org/documentation/2.0/admin/install">the documentation</a> to learn how to create the <strong>config.php</strong> file manually.'] = '';
$GLOBALS['__l10n']['System information'] = '';
$GLOBALS['__l10n']['Please provide the following information needed to create your configuration file.'] = '';
$GLOBALS['__l10n']['Database type:'] = '';
$GLOBALS['__l10n']['MySQL (deprecated)'] = '';
$GLOBALS['__l10n']['MySQLi'] = '';
$GLOBALS['__l10n']['PostgreSQL'] = '';
$GLOBALS['__l10n']['Database Host Name:'] = '';
$GLOBALS['__l10n']['Database Name:'] = '';
$GLOBALS['__l10n']['Database User Name:'] = '';
$GLOBALS['__l10n']['Database Password:'] = '';
$GLOBALS['__l10n']['Database Tables Prefix:'] = '';
$GLOBALS['__l10n']['Continue'] = '';
$GLOBALS['__l10n']['No such installed language'] = '';
$GLOBALS['__l10n']['You can\'t remove English language.'] = '';
$GLOBALS['__l10n']['Permissions to delete language denied.'] = '';
$GLOBALS['__l10n']['Language has been successfully deleted.'] = '';
$GLOBALS['__l10n']['Invalid language file URL.'] = '';
$GLOBALS['__l10n']['Language has been successfully upgraded'] = '';
$GLOBALS['__l10n']['Language has been successfully installed.'] = '';
$GLOBALS['__l10n']['Unable to move uploaded file.'] = '';
$GLOBALS['__l10n']['Languages management'] = '';
$GLOBALS['__l10n']['Here you can install, upgrade or remove languages for your Dotclear installation.'] = '';
$GLOBALS['__l10n']['You can change your user language in your <a href="%1$s">preferences</a> or change your blog\'s main language in your <a href="%2$s">blog settings</a>.'] = '';
$GLOBALS['__l10n']['Installed languages'] = '';
$GLOBALS['__l10n']['No additional language is installed.'] = '';
$GLOBALS['__l10n']['Language'] = '';
$GLOBALS['__l10n']['Action'] = '';
$GLOBALS['__l10n']['Install or upgrade languages'] = '';
$GLOBALS['__l10n']['You can install or remove a language by adding or removing the relevant directory in your %s folder.'] = '';
$GLOBALS['__l10n']['Available languages'] = '';
$GLOBALS['__l10n']['You can download and install a additional language directly from Dotclear.net. Proposed languages are based on your version: %s.'] = '';
$GLOBALS['__l10n']['Language:'] = '';
$GLOBALS['__l10n']['Install language'] = '';
$GLOBALS['__l10n']['Upload a zip file'] = '';
$GLOBALS['__l10n']['You can install languages by uploading zip files.'] = '';
$GLOBALS['__l10n']['Language zip file:'] = '';
$GLOBALS['__l10n']['Upload language'] = '';
$GLOBALS['__l10n']['Invalid language zip file.'] = '';
$GLOBALS['__l10n']['The zip file does not appear to be a valid Dotclear language pack.'] = '';
$GLOBALS['__l10n']['An error occurred during language upgrade.'] = '';
$GLOBALS['__l10n']['By names, in ascending order'] = '';
$GLOBALS['__l10n']['By names, in descending order'] = '';
$GLOBALS['__l10n']['By dates, in ascending order'] = '';
$GLOBALS['__l10n']['By dates, in descending order'] = '';
$GLOBALS['__l10n']['Directory "%s" has been successfully created.'] = '';
$GLOBALS['__l10n']['Files have been successfully uploaded.'] = '';
$GLOBALS['__l10n']['Successfully delete one media.'][0] = '';
$GLOBALS['__l10n']['Successfully delete one media.'][1] = '';
$GLOBALS['__l10n']['Directory has been successfully removed.'] = '';
$GLOBALS['__l10n']['File has been successfully removed.'] = '';
$GLOBALS['__l10n']['Directory "%s" has been successfully rebuilt.'] = '';
$GLOBALS['__l10n']['Media manager'] = '';
$GLOBALS['__l10n']['confirm removal'] = '';
$GLOBALS['__l10n']['Are you sure you want to remove %s?'] = '';
$GLOBALS['__l10n']['Cancel'] = '';
$GLOBALS['__l10n']['Yes'] = '';
$GLOBALS['__l10n']['You do not have sufficient permissions to write to this folder.'] = '';
$GLOBALS['__l10n']['Directory has been successfully created.'] = '';
$GLOBALS['__l10n']['Directory has been successfully rebuilt.'] = '';
$GLOBALS['__l10n']['Zip file has been successfully extracted.'] = '';
$GLOBALS['__l10n']['Choose a file to attach to entry %s by clicking on %s.'] = '';
$GLOBALS['__l10n']['Attach this file to entry'] = '';
$GLOBALS['__l10n']['Choose a file to insert into entry by clicking on %s.'] = '';
$GLOBALS['__l10n']['Remove selected medias'] = '';
$GLOBALS['__l10n']['No file.'] = '';
$GLOBALS['__l10n']['Sort files:'] = '';
$GLOBALS['__l10n']['Number of elements displayed per page:'] = '';
$GLOBALS['__l10n']['In %s:'] = '';
$GLOBALS['__l10n']['Create new directory'] = '';
$GLOBALS['__l10n']['Directory Name:'] = '';
$GLOBALS['__l10n']['Backup content of %s'] = '';
$GLOBALS['__l10n']['Download zip file'] = '';
$GLOBALS['__l10n']['Add files'] = '';
$GLOBALS['__l10n']['Please take care to publish media that you own and that are not protected by copyright.'] = '';
$GLOBALS['__l10n']['Choose file'] = '';
$GLOBALS['__l10n']['Choose files'] = '';
$GLOBALS['__l10n']['Maximum file size allowed:'] = '';
$GLOBALS['__l10n']['Private'] = '';
$GLOBALS['__l10n']['To send several files at the same time, you can activate the enhanced uploader in'] = '';
$GLOBALS['__l10n']['My preferences'] = '';
$GLOBALS['__l10n']['Refresh'] = '';
$GLOBALS['__l10n']['Clear all'] = '';
$GLOBALS['__l10n']['Upload'] = '';
$GLOBALS['__l10n']['Current settings for medias and images are defined in %s'] = '';
$GLOBALS['__l10n']['Blog parameters'] = '';
$GLOBALS['__l10n']['open'] = '';
$GLOBALS['__l10n']['Insert this file into entry'] = '';
$GLOBALS['__l10n']['delete'] = '';
$GLOBALS['__l10n']['Not a valid file'] = '';
$GLOBALS['__l10n']['File has been successfully updated.'] = '';
$GLOBALS['__l10n']['Thumbnails have been successfully updated.'] = '';
$GLOBALS['__l10n']['Default media insertion settings have been successfully updated.'] = '';
$GLOBALS['__l10n']['Are you sure to delete this media?'] = '';
$GLOBALS['__l10n']['Insert media item'] = '';
$GLOBALS['__l10n']['Image size:'] = '';
$GLOBALS['__l10n']['Image alignment'] = '';
$GLOBALS['__l10n']['Image insertion'] = '';
$GLOBALS['__l10n']['As a single image'] = '';
$GLOBALS['__l10n']['As a link to the original image'] = '';
$GLOBALS['__l10n']['MP3 disposition'] = '';
$GLOBALS['__l10n']['Please note that you cannot insert mp3 files with visual editor.'] = '';
$GLOBALS['__l10n']['Please note that you cannot insert video files with visual editor.'] = '';
$GLOBALS['__l10n']['Video size'] = '';
$GLOBALS['__l10n']['Width:'] = '';
$GLOBALS['__l10n']['Height:'] = '';
$GLOBALS['__l10n']['Video disposition'] = '';
$GLOBALS['__l10n']['Media item will be inserted as a link.'] = '';
$GLOBALS['__l10n']['Insert'] = '';
$GLOBALS['__l10n']['Make current settings as default'] = '';
$GLOBALS['__l10n']['Media details'] = '';
$GLOBALS['__l10n']['Available sizes:'] = '';
$GLOBALS['__l10n']['File owner:'] = '';
$GLOBALS['__l10n']['File type:'] = '';
$GLOBALS['__l10n']['File size:'] = '';
$GLOBALS['__l10n']['File URL:'] = '';
$GLOBALS['__l10n']['Show entries containing this media'] = '';
$GLOBALS['__l10n']['Entries containing this media'] = '';
$GLOBALS['__l10n']['No entry seems contain this media.'] = '';
$GLOBALS['__l10n']['published'] = '';
$GLOBALS['__l10n']['unpublished'] = '';
$GLOBALS['__l10n']['scheduled'] = '';
$GLOBALS['__l10n']['pending'] = '';
$GLOBALS['__l10n']['Image details'] = '';
$GLOBALS['__l10n']['No detail'] = '';
$GLOBALS['__l10n']['Updates and modifications'] = '';
$GLOBALS['__l10n']['Update thumbnails'] = '';
$GLOBALS['__l10n']['This will create or update thumbnails for this image.'] = '';
$GLOBALS['__l10n']['Extract in a new directory'] = '';
$GLOBALS['__l10n']['Extract in current directory'] = '';
$GLOBALS['__l10n']['Extract archive'] = '';
$GLOBALS['__l10n']['This will extract archive in a new directory that should not exist yet.'] = '';
$GLOBALS['__l10n']['This will extract archive in current directory and will overwrite existing files or directory.'] = '';
$GLOBALS['__l10n']['Extract mode:'] = '';
$GLOBALS['__l10n']['Extract'] = '';
$GLOBALS['__l10n']['Change media properties'] = '';
$GLOBALS['__l10n']['File name:'] = '';
$GLOBALS['__l10n']['File title:'] = '';
$GLOBALS['__l10n']['File date:'] = '';
$GLOBALS['__l10n']['New directory:'] = '';
$GLOBALS['__l10n']['Change file'] = '';
$GLOBALS['__l10n']['Choose a file:'] = '';
$GLOBALS['__l10n']['Maximum size %s'] = '';
$GLOBALS['__l10n']['Send'] = '';
$GLOBALS['__l10n']['Delete this media'] = '';
$GLOBALS['__l10n']['No content found on this plugin.'] = '';
$GLOBALS['__l10n']['Plugin not found'] = '';
$GLOBALS['__l10n']['The plugin you reached does not exist or does not have an admin page.'] = '';
$GLOBALS['__l10n']['Plugins management'] = '';
$GLOBALS['__l10n']['Plugin configuration'] = '';
$GLOBALS['__l10n']['Update plugins'] = '';
$GLOBALS['__l10n']['There is one plugin to update available from repository.'][0] = '';
$GLOBALS['__l10n']['There is one plugin to update available from repository.'][1] = '';
$GLOBALS['__l10n']['Installed plugins'] = '';
$GLOBALS['__l10n']['Activated plugins'] = '';
$GLOBALS['__l10n']['You can configure and manage installed plugins from this list.'] = '';
$GLOBALS['__l10n']['Deactivated plugins'] = '';
$GLOBALS['__l10n']['Deactivated plugins are installed but not usable. You can activate them from here.'] = '';
$GLOBALS['__l10n']['Add plugins'] = '';
$GLOBALS['__l10n']['Add plugins from repository'] = '';
$GLOBALS['__l10n']['Add plugins from a package'] = '';
$GLOBALS['__l10n']['You can install plugins by uploading or downloading zip files.'] = '';
$GLOBALS['__l10n']['Some functions are disabled, please give write access to your plugins directory to enable them.'] = '';
$GLOBALS['__l10n']['Add a link'] = '';
$GLOBALS['__l10n']['Link URL:'] = '';
$GLOBALS['__l10n']['Link title:'] = '';
$GLOBALS['__l10n']['Link language:'] = '';
$GLOBALS['__l10n']['Add a link to an entry'] = '';
$GLOBALS['__l10n']['Entry type:'] = '';
$GLOBALS['__l10n']['Ok'] = '';
$GLOBALS['__l10n']['Search entry:'] = '';
$GLOBALS['__l10n']['Search'] = '';
$GLOBALS['__l10n']['cancel'] = '';
$GLOBALS['__l10n']['Edit entry'] = '';
$GLOBALS['__l10n']['This entry does not exist.'] = '';
$GLOBALS['__l10n']['Next entry'] = '';
$GLOBALS['__l10n']['Previous entry'] = '';
$GLOBALS['__l10n']['All pings sent.'] = '';
$GLOBALS['__l10n']['Invalid publication date'] = '';
$GLOBALS['__l10n']['The post "%s" has been successfully updated'] = '';
$GLOBALS['__l10n']['Entry has been successfully created.'] = '';
$GLOBALS['__l10n']['Published'] = '';
$GLOBALS['__l10n']['Unpublished'] = '';
$GLOBALS['__l10n']['Scheduled'] = '';
$GLOBALS['__l10n']['Pending'] = '';
$GLOBALS['__l10n']['&ldquo;%s&rdquo;'] = '';
$GLOBALS['__l10n']['Entries'] = '';
$GLOBALS['__l10n']['Entry has been successfully updated.'] = '';
$GLOBALS['__l10n']['File has been successfully attached.'] = '';
$GLOBALS['__l10n']['Attachment has been successfully removed.'] = '';
$GLOBALS['__l10n']['Don\'t forget to validate your XHTML conversion by saving your post.'] = '';
$GLOBALS['__l10n']['Go to this entry on the site'] = '';
$GLOBALS['__l10n']['Entry status'] = '';
$GLOBALS['__l10n']['Publication date and hour'] = '';
$GLOBALS['__l10n']['Entry language'] = '';
$GLOBALS['__l10n']['Text formatting'] = '';
$GLOBALS['__l10n']['Convert to XHTML'] = '';
$GLOBALS['__l10n']['Filing'] = '';
$GLOBALS['__l10n']['Selected entry'] = '';
$GLOBALS['__l10n']['Category'] = '';
$GLOBALS['__l10n']['Options'] = '';
$GLOBALS['__l10n']['Comments and trackbacks list'] = '';
$GLOBALS['__l10n']['Warning: Comments are not more accepted for this entry.'] = '';
$GLOBALS['__l10n']['Comments are not accepted on this blog so far.'] = '';
$GLOBALS['__l10n']['Warning: Trackbacks are not more accepted for this entry.'] = '';
$GLOBALS['__l10n']['Trackbacks are not accepted on this blog so far.'] = '';
$GLOBALS['__l10n']['Password'] = '';
$GLOBALS['__l10n']['Edit basename'] = '';
$GLOBALS['__l10n']['Warning: If you set the URL manually, it may conflict with another entry.'] = '';
$GLOBALS['__l10n']['Excerpt:'] = '';
$GLOBALS['__l10n']['Introduction to the post.'] = '';
$GLOBALS['__l10n']['Personal notes:'] = '';
$GLOBALS['__l10n']['Unpublished notes.'] = '';
$GLOBALS['__l10n']['Edit post'] = '';
$GLOBALS['__l10n']['Preview'] = '';
$GLOBALS['__l10n']['Comments'] = '';
$GLOBALS['__l10n']['Add a comment'] = '';
$GLOBALS['__l10n']['Trackbacks'] = '';
$GLOBALS['__l10n']['Trackbacks received'] = '';
$GLOBALS['__l10n']['No trackback'] = '';
$GLOBALS['__l10n']['Selected trackbacks action:'] = '';
$GLOBALS['__l10n']['Ping blogs'] = '';
$GLOBALS['__l10n']['URLs to ping:'] = '';
$GLOBALS['__l10n']['Excerpt to send:'] = '';
$GLOBALS['__l10n']['Auto discover ping URLs'] = '';
$GLOBALS['__l10n']['Previously sent pings'] = '';
$GLOBALS['__l10n']['IP address'] = '';
$GLOBALS['__l10n']['Edit'] = '';
$GLOBALS['__l10n']['Junk'] = '';
$GLOBALS['__l10n']['select this comment'] = '';
$GLOBALS['__l10n']['select this trackback'] = '';
$GLOBALS['__l10n']['Edit this comment'] = '';
$GLOBALS['__l10n']['This attachment does not exist'] = '';
$GLOBALS['__l10n']['Remove attachment'] = '';
$GLOBALS['__l10n']['Attachment'] = '';
$GLOBALS['__l10n']['Are you sure you want to remove this attachment?'] = '';
$GLOBALS['__l10n']['(No cat)'] = '(none)';
$GLOBALS['__l10n']['Selected'] = '';
$GLOBALS['__l10n']['Not selected'] = '';
$GLOBALS['__l10n']['With attachments'] = '';
$GLOBALS['__l10n']['Without attachments'] = '';
$GLOBALS['__l10n']['Number of comments'] = '';
$GLOBALS['__l10n']['Number of trackbacks'] = '';
$GLOBALS['__l10n']['Selected entries have been successfully updated.'] = '';
$GLOBALS['__l10n']['Selected entries have been successfully deleted.'] = '';
$GLOBALS['__l10n']['Selected:'] = '';
$GLOBALS['__l10n']['Attachments:'] = '';
$GLOBALS['__l10n']['Month:'] = '';
$GLOBALS['__l10n']['Lang:'] = '';
$GLOBALS['__l10n']['entries per page'] = '';
$GLOBALS['__l10n']['Selected entries action:'] = '';
$GLOBALS['__l10n']['If you want to change your email or password you must provide your current password.'] = '';
$GLOBALS['__l10n']['Personal information has been successfully updated.'] = '';
$GLOBALS['__l10n']['Personal options has been successfully updated.'] = '';
$GLOBALS['__l10n']['Dashboard options has been successfully updated.'] = '';
$GLOBALS['__l10n']['No favorite selected'] = '';
$GLOBALS['__l10n']['Favorites have been successfully added.'] = '';
$GLOBALS['__l10n']['Favorites have been successfully removed.'] = '';
$GLOBALS['__l10n']['Favorites have been successfully updated.'] = '';
$GLOBALS['__l10n']['Default favorites have been successfully updated.'] = '';
$GLOBALS['__l10n']['My profile'] = '';
$GLOBALS['__l10n']['Display name:'] = '';
$GLOBALS['__l10n']['Language for my interface:'] = '';
$GLOBALS['__l10n']['My timezone:'] = '';
$GLOBALS['__l10n']['Change my password'] = '';
$GLOBALS['__l10n']['Confirm new password:'] = '';
$GLOBALS['__l10n']['Your current password:'] = '';
$GLOBALS['__l10n']['If you have changed your email or password you must provide your current password to save these modifications.'] = '';
$GLOBALS['__l10n']['Update my profile'] = '';
$GLOBALS['__l10n']['My options'] = '';
$GLOBALS['__l10n']['Interface'] = '';
$GLOBALS['__l10n']['Activate enhanced uploader in media manager'] = '';
$GLOBALS['__l10n']['Disable javascript powered drag and drop for ordering items'] = '';
$GLOBALS['__l10n']['If checked, numeric fields will allow to type the elements\' ordering number.'] = '';
$GLOBALS['__l10n']['Number of elements displayed per page in media manager:'] = '';
$GLOBALS['__l10n']['Do not use standard favicon'] = '';
$GLOBALS['__l10n']['This will be applied for all users'] = '';
$GLOBALS['__l10n']['Edition'] = '';
$GLOBALS['__l10n']['Preferred editor for %s:'] = '';
$GLOBALS['__l10n']['Choose an editor'] = '';
$GLOBALS['__l10n']['Preferred format:'] = '';
$GLOBALS['__l10n']['Default entry status:'] = '';
$GLOBALS['__l10n']['Entry edit field height:'] = '';
$GLOBALS['__l10n']['Enable WYSIWYG mode'] = '';
$GLOBALS['__l10n']['Other options'] = '';
$GLOBALS['__l10n']['Save my options'] = '';
$GLOBALS['__l10n']['My dashboard'] = '';
$GLOBALS['__l10n']['My favorites'] = '';
$GLOBALS['__l10n']['position of %s'] = '';
$GLOBALS['__l10n']['Save order'] = '';
$GLOBALS['__l10n']['Delete selected favorites'] = '';
$GLOBALS['__l10n']['Are you sure you want to remove selected favorites?'] = '';
$GLOBALS['__l10n']['If you are a super administrator, you may define this set of favorites to be used by default on all blogs of this installation.'] = '';
$GLOBALS['__l10n']['Define as default favorites'] = '';
$GLOBALS['__l10n']['Currently no personal favorites.'] = '';
$GLOBALS['__l10n']['Other available favorites'] = '';
$GLOBALS['__l10n']['(default favorite)'] = '';
$GLOBALS['__l10n']['Add to my favorites'] = '';
$GLOBALS['__l10n']['Menu'] = '';
$GLOBALS['__l10n']['Display favorites at the top of the menu'] = '';
$GLOBALS['__l10n']['Dashboard icons'] = '';
$GLOBALS['__l10n']['Iconset:'] = '';
$GLOBALS['__l10n']['Dashboard modules'] = '';
$GLOBALS['__l10n']['Display documentation links'] = '';
$GLOBALS['__l10n']['Display Dotclear news'] = '';
$GLOBALS['__l10n']['Display quick entry form'] = '';
$GLOBALS['__l10n']['Save my dashboard options'] = '';
$GLOBALS['__l10n']['Search options'] = '';
$GLOBALS['__l10n']['Query:'] = '';
$GLOBALS['__l10n']['Search in entries'] = '';
$GLOBALS['__l10n']['Search in comments'] = '';
$GLOBALS['__l10n']['%d entries found'] = '';
$GLOBALS['__l10n']['%d entry found'] = '';
$GLOBALS['__l10n']['%d comment found'] = '';
$GLOBALS['__l10n']['%d comments found'] = '';
$GLOBALS['__l10n']['Dotclear update'] = '';
$GLOBALS['__l10n']['Unable to delete file %s'] = '';
$GLOBALS['__l10n']['Downloaded Dotclear archive seems to be corrupted. Try <a %s>download it</a> again.'] = '';
$GLOBALS['__l10n']['If this problem persists try to <a href="http://dotclear.org/download">update manually</a>.'] = '';
$GLOBALS['__l10n']['The following files of your Dotclear installation have been modified so we won\'t try to update your installation. Please try to <a href="http://dotclear.org/download">update manually</a>.'] = '';
$GLOBALS['__l10n']['The following files of your Dotclear installation are not readable. Please fix this or try to make a backup file named %s manually.'] = '';
$GLOBALS['__l10n']['The following files of your Dotclear installation cannot be written. Please fix this or try to <a href="http://dotclear.org/download">update manually</a>.'] = '';
$GLOBALS['__l10n']['Manual checking of update done successfully.'] = '';
$GLOBALS['__l10n']['No newer Dotclear version available.'] = '';
$GLOBALS['__l10n']['Force checking update Dotclear'] = '';
$GLOBALS['__l10n']['Dotclear %s is available.'] = '';
$GLOBALS['__l10n']['To upgrade your Dotclear installation simply click on the following button. A backup file of your current installation will be created in your root directory.'] = '';
$GLOBALS['__l10n']['Update Dotclear'] = '';
$GLOBALS['__l10n']['Manage backup files'] = '';
$GLOBALS['__l10n']['Update backup files'] = '';
$GLOBALS['__l10n']['The following files are backups of previously updates. You can revert your previous installation or delete theses files.'] = '';
$GLOBALS['__l10n']['Please note that reverting your Dotclear version may have some unwanted side-effects. Consider reverting only if you experience strong issues with this new version.'] = '';
$GLOBALS['__l10n']['You should not revert to version prior to last one (%s).'] = '';
$GLOBALS['__l10n']['Delete selected file'] = '';
$GLOBALS['__l10n']['Revert to selected file'] = '';
$GLOBALS['__l10n']['Congratulations, you\'re one click away from the end of the update.'] = '';
$GLOBALS['__l10n']['Finish the update.'] = '';
$GLOBALS['__l10n']['New user'] = '';
$GLOBALS['__l10n']['User has been successfully updated.'] = '';
$GLOBALS['__l10n']['User "%s" already exists.'] = '';
$GLOBALS['__l10n']['User has been successfully created.'] = '';
$GLOBALS['__l10n']['User profile'] = '';
$GLOBALS['__l10n']['User ID:'] = '';
$GLOBALS['__l10n']['Warning:'] = '';
$GLOBALS['__l10n']['If you change your username, you will have to log in again.'] = '';
$GLOBALS['__l10n']['Password change required to connect'] = '';
$GLOBALS['__l10n']['Mandatory for password recovering procedure.'] = '';
$GLOBALS['__l10n']['Timezone:'] = '';
$GLOBALS['__l10n']['Save and create another'] = '';
$GLOBALS['__l10n']['Permissions'] = '';
$GLOBALS['__l10n']['Add new permissions'] = '';
$GLOBALS['__l10n']['No permissions so far.'] = '';
$GLOBALS['__l10n']['Blog:'] = '';
$GLOBALS['__l10n']['%s is super admin (all rights on all blogs).'] = '';
$GLOBALS['__l10n']['Username'] = '';
$GLOBALS['__l10n']['Last Name'] = '';
$GLOBALS['__l10n']['First Name'] = '';
$GLOBALS['__l10n']['Display name'] = '';
$GLOBALS['__l10n']['Number of entries'] = '';
$GLOBALS['__l10n']['Set permissions'] = '';
$GLOBALS['__l10n']['User has been successfully removed.'] = '';
$GLOBALS['__l10n']['The permissions have been successfully updated.'] = '';
$GLOBALS['__l10n']['users per page'] = '';
$GLOBALS['__l10n']['Selected users action:'] = '';
$GLOBALS['__l10n']['No blog or user given.'] = '';
$GLOBALS['__l10n']['You cannot delete yourself.'] = '';
$GLOBALS['__l10n']['User has been successfully deleted.'] = '';
$GLOBALS['__l10n']['Back to user profile'] = '';
$GLOBALS['__l10n']['Choose one or more blogs to which you want to give permissions to users %s.'] = '';
$GLOBALS['__l10n']['select'] = '';
$GLOBALS['__l10n']['You are about to change permissions on the following blogs for users %s.'] = '';
$GLOBALS['__l10n']['Validate permissions'] = '';
$GLOBALS['__l10n']['Back to comments list'] = '';
$GLOBALS['__l10n']['Comments actions'] = '';
$GLOBALS['__l10n']['Publish'] = '';
$GLOBALS['__l10n']['Unpublish'] = '';
$GLOBALS['__l10n']['Mark as pending'] = '';
$GLOBALS['__l10n']['Mark as junk'] = '';
$GLOBALS['__l10n']['No comment selected'] = '';
$GLOBALS['__l10n']['Back to entries list'] = '';
$GLOBALS['__l10n']['Entries actions'] = '';
$GLOBALS['__l10n']['Schedule'] = '';
$GLOBALS['__l10n']['Mark'] = '';
$GLOBALS['__l10n']['Mark as selected'] = '';
$GLOBALS['__l10n']['Mark as unselected'] = '';
$GLOBALS['__l10n']['Change'] = '';
$GLOBALS['__l10n']['Change category'] = '';
$GLOBALS['__l10n']['Change language'] = '';
$GLOBALS['__l10n']['Change author'] = '';
$GLOBALS['__l10n']['No entry selected'] = '';
$GLOBALS['__l10n']['%d entry has been successfully updated to status : "%s"'][0] = '';
$GLOBALS['__l10n']['%d entry has been successfully updated to status : "%s"'][1] = '';
$GLOBALS['__l10n']['%d entry has been successfully marked as selected'][0] = '';
$GLOBALS['__l10n']['%d entry has been successfully marked as selected'][1] = '';
$GLOBALS['__l10n']['%d entry has been successfully marked as unselected'][0] = '';
$GLOBALS['__l10n']['%d entry has been successfully marked as unselected'][1] = '';
$GLOBALS['__l10n']['%d entry has been successfully deleted'][0] = '';
$GLOBALS['__l10n']['%d entry has been successfully deleted'][1] = '';
$GLOBALS['__l10n']['%d entry has been successfully moved to category "%s"'][0] = '';
$GLOBALS['__l10n']['%d entry has been successfully moved to category "%s"'][1] = '';
$GLOBALS['__l10n']['Change category for this selection'] = '';
$GLOBALS['__l10n']['Create a new category for the post(s)'] = '';
$GLOBALS['__l10n']['This user does not exist'] = '';
$GLOBALS['__l10n']['%d entry has been successfully set to user "%s"'][0] = '';
$GLOBALS['__l10n']['%d entry has been successfully set to user "%s"'][1] = '';
$GLOBALS['__l10n']['Change author for this selection'] = '';
$GLOBALS['__l10n']['New author (author ID):'] = '';
$GLOBALS['__l10n']['%d entry has been successfully set to language "%s"'][0] = '';
$GLOBALS['__l10n']['%d entry has been successfully set to language "%s"'][1] = '';
$GLOBALS['__l10n']['Change language for this selection'] = '';
$GLOBALS['__l10n']['Available'] = '';
$GLOBALS['__l10n']['Most used'] = '';
$GLOBALS['__l10n']['Entry language:'] = '';
$GLOBALS['__l10n']['Languages'] = '';
$GLOBALS['__l10n']['%d comment'][0] = '';
$GLOBALS['__l10n']['%d comment'][1] = '';
$GLOBALS['__l10n']['Change blog'] = '';
$GLOBALS['__l10n']['Blogs:'] = '';
$GLOBALS['__l10n']['Go to the content'] = '';
$GLOBALS['__l10n']['Go to the menu'] = '';
$GLOBALS['__l10n']['Go to search'] = '';
$GLOBALS['__l10n']['Go to help'] = '';
$GLOBALS['__l10n']['Go to site'] = '';
$GLOBALS['__l10n']['Logout %s'] = '';
$GLOBALS['__l10n']['Hide main menu'] = '';
$GLOBALS['__l10n']['Show main menu'] = '';
$GLOBALS['__l10n']['Safe mode'] = '';
$GLOBALS['__l10n']['You are in safe mode. All plugins have been temporarily disabled. Remind to log out then log in again normally to get back all functionalities'] = '';
$GLOBALS['__l10n']['[%H:%M:%S]'] = '';
$GLOBALS['__l10n']['Thank you for using %s.'] = '';
$GLOBALS['__l10n']['Go to dashboard'] = '';
$GLOBALS['__l10n']['Help about this page'] = '';
$GLOBALS['__l10n']['See also %s'] = '';
$GLOBALS['__l10n']['the global help'] = '';
$GLOBALS['__l10n']['uncover'] = '';
$GLOBALS['__l10n']['hide'] = '';
$GLOBALS['__l10n']['Need help?'] = '';
$GLOBALS['__l10n']['new window'] = '';
$GLOBALS['__l10n']['Hide'] = '';
$GLOBALS['__l10n']['Select:'] = '';
$GLOBALS['__l10n']['no selection'] = '';
$GLOBALS['__l10n']['select all'] = '';
$GLOBALS['__l10n']['Invert selection'] = '';
$GLOBALS['__l10n']['view entry'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete selected entries (%s)?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete selected medias (%d)?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete selected categories (%s)?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete this entry?'] = '';
$GLOBALS['__l10n']['Click here to unlock the field'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete all spams?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete selected comments (%s)?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete this comment?'] = '';
$GLOBALS['__l10n']['Users with posts cannot be deleted.'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete selected users (%s)?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete category "%s"?'] = '';
$GLOBALS['__l10n']['Are you sure you want to reorder all categories?'] = '';
$GLOBALS['__l10n']['Are you sure you want to remove media "%s"?'] = '';
$GLOBALS['__l10n']['Are you sure you want to remove directory "%s"?'] = '';
$GLOBALS['__l10n']['Are you sure you want to extract archive in current directory?'] = '';
$GLOBALS['__l10n']['Are you sure you want to remove attachment "%s"?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete "%s" language?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete "%s" plugin?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete selected plugins?'] = '';
$GLOBALS['__l10n']['Use this theme'] = '';
$GLOBALS['__l10n']['Remove this theme'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete "%s" theme?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete selected themes?'] = '';
$GLOBALS['__l10n']['Are you sure you want to delete this backup?'] = '';
$GLOBALS['__l10n']['Are you sure you want to revert to this backup?'] = '';
$GLOBALS['__l10n']['Zip file content'] = '';
$GLOBALS['__l10n']['XHTML markup validator'] = '';
$GLOBALS['__l10n']['XHTML content is valid.'] = '';
$GLOBALS['__l10n']['There are XHTML markup errors.'] = '';
$GLOBALS['__l10n']['Attention: an audit of a content not yet registered.'] = '';
$GLOBALS['__l10n']['You have unsaved changes. Switch post format will loose these changes. Proceed anyway?'] = '';
$GLOBALS['__l10n']['Warning: post format change will not convert existing content. You will need to apply new format by yourself. Proceed anyway?'] = '';
$GLOBALS['__l10n']['Loading enhanced uploader, please wait.'] = '';
$GLOBALS['__l10n']['Details'] = '';
$GLOBALS['__l10n']['Support'] = '';
$GLOBALS['__l10n']['Help:'] = '';
$GLOBALS['__l10n']['Section:'] = '';
$GLOBALS['__l10n']['Tags:'] = '';
$GLOBALS['__l10n']['You have unsaved changes.'] = '';
$GLOBALS['__l10n']['Choose date'] = '';
$GLOBALS['__l10n']['close'] = '';
$GLOBALS['__l10n']['now'] = '';
$GLOBALS['__l10n']['Temporarily activate enhanced uploader'] = '';
$GLOBALS['__l10n']['Temporarily disable enhanced uploader'] = '';
$GLOBALS['__l10n']['Limit exceeded.'] = '';
$GLOBALS['__l10n']['File size exceeds allowed limit.'] = '';
$GLOBALS['__l10n']['Canceled.'] = '';
$GLOBALS['__l10n']['HTTP Error:'] = '';
$GLOBALS['__l10n']['Clean'] = '';
$GLOBALS['__l10n']['File successfully uploaded.'] = '';
$GLOBALS['__l10n']['No file in queue.'] = '';
$GLOBALS['__l10n']['1 file in queue.'] = '';
$GLOBALS['__l10n']['%d files in queue.'] = '';
$GLOBALS['__l10n']['Queue error:'] = '';
$GLOBALS['__l10n']['other'] = '';
$GLOBALS['__l10n']['Search in repository:'] = '';
$GLOBALS['__l10n']['Reset search'] = '';
$GLOBALS['__l10n']['Search is allowed on multiple terms longer than 2 chars, terms must be separated by space.'] = '';
$GLOBALS['__l10n']['Found %d result for search "%s":'][0] = '';
$GLOBALS['__l10n']['Found %d result for search "%s":'][1] = '';
$GLOBALS['__l10n']['current selection'] = '';
$GLOBALS['__l10n']['%d result'][0] = '';
$GLOBALS['__l10n']['%d result'][1] = '';
$GLOBALS['__l10n']['no results'] = '';
$GLOBALS['__l10n']['Browse index:'] = '';
$GLOBALS['__l10n']['Plugins list'] = '';
$GLOBALS['__l10n']['Name'] = '';
$GLOBALS['__l10n']['Score'] = '';
$GLOBALS['__l10n']['Version'] = '';
$GLOBALS['__l10n']['Current version'] = '';
$GLOBALS['__l10n']['Plugin from official distribution'] = '';
$GLOBALS['__l10n']['Configure plugin'] = '';
$GLOBALS['__l10n']['No plugins matched your search.'] = '';
$GLOBALS['__l10n']['Activate'] = '';
$GLOBALS['__l10n']['Deactivate'] = '';
$GLOBALS['__l10n']['Install'] = '';
$GLOBALS['__l10n']['Update'] = '';
$GLOBALS['__l10n']['Activate selected plugins'] = '';
$GLOBALS['__l10n']['Activate all plugins from this list'] = '';
$GLOBALS['__l10n']['Deactivate selected plugins'] = '';
$GLOBALS['__l10n']['Deactivate all plugins from this list'] = '';
$GLOBALS['__l10n']['Update selected plugins'] = '';
$GLOBALS['__l10n']['Update all plugins from this list'] = '';
$GLOBALS['__l10n']['No such plugin.'] = '';
$GLOBALS['__l10n']['You don\'t have permissions to delete this plugin.'] = '';
$GLOBALS['__l10n']['Some plugins have not been delete.'] = '';
$GLOBALS['__l10n']['Plugin has been successfully deleted.'][0] = '';
$GLOBALS['__l10n']['Plugin has been successfully deleted.'][1] = '';
$GLOBALS['__l10n']['Plugin has been successfully installed.'][0] = '';
$GLOBALS['__l10n']['Plugin has been successfully installed.'][1] = '';
$GLOBALS['__l10n']['Plugin has been successfully activated.'][0] = '';
$GLOBALS['__l10n']['Plugin has been successfully activated.'][1] = '';
$GLOBALS['__l10n']['Some plugins have not been deactivated.'] = '';
$GLOBALS['__l10n']['Plugin has been successfully deactivated.'][0] = '';
$GLOBALS['__l10n']['Plugin has been successfully deactivated.'][1] = '';
$GLOBALS['__l10n']['Plugin has been successfully updated.'][0] = '';
$GLOBALS['__l10n']['Plugin has been successfully updated.'][1] = '';
$GLOBALS['__l10n']['Zip file path:'] = '';
$GLOBALS['__l10n']['Download a zip file'] = '';
$GLOBALS['__l10n']['Zip file URL:'] = '';
$GLOBALS['__l10n']['Download'] = '';
$GLOBALS['__l10n']['Unknow plugin ID'] = '';
$GLOBALS['__l10n']['This plugin has no configuration file.'] = '';
$GLOBALS['__l10n']['Configure "%s"'] = '';
$GLOBALS['__l10n']['Back'] = '';
$GLOBALS['__l10n']['Score: %s'] = '';
$GLOBALS['__l10n']['%s screenshot.'] = '';
$GLOBALS['__l10n']['by %s'] = '';
$GLOBALS['__l10n']['version %s'] = '';
$GLOBALS['__l10n']['(current version %s)'] = '';
$GLOBALS['__l10n']['(built on "%s")'] = '';
$GLOBALS['__l10n']['(requires "%s")'] = '';
$GLOBALS['__l10n']['View stylesheet'] = '';
$GLOBALS['__l10n']['Configure theme'] = '';
$GLOBALS['__l10n']['No themes matched your search.'] = '';
$GLOBALS['__l10n']['Use this one'] = '';
$GLOBALS['__l10n']['Update selected themes'] = '';
$GLOBALS['__l10n']['Update all themes from this list'] = '';
$GLOBALS['__l10n']['No such theme.'] = '';
$GLOBALS['__l10n']['Theme has been successfully selected.'] = '';
$GLOBALS['__l10n']['Theme has been successfully activated.'][0] = '';
$GLOBALS['__l10n']['Theme has been successfully activated.'][1] = '';
$GLOBALS['__l10n']['Some themes have not been deactivated.'] = '';
$GLOBALS['__l10n']['Theme has been successfully deactivated.'][0] = '';
$GLOBALS['__l10n']['Theme has been successfully deactivated.'][1] = '';
$GLOBALS['__l10n']['You don\'t have permissions to delete this theme.'] = '';
$GLOBALS['__l10n']['Some themes have not been delete.'] = '';
$GLOBALS['__l10n']['Theme has been successfully deleted.'][0] = '';
$GLOBALS['__l10n']['Theme has been successfully deleted.'][1] = '';
$GLOBALS['__l10n']['Theme has been successfully installed.'][0] = '';
$GLOBALS['__l10n']['Theme has been successfully installed.'][1] = '';
$GLOBALS['__l10n']['Theme has been successfully updated.'][0] = '';
$GLOBALS['__l10n']['Theme has been successfully updated.'][1] = '';
$GLOBALS['__l10n']['First page'] = '';
$GLOBALS['__l10n']['Previous page'] = '';
$GLOBALS['__l10n']['Next page'] = '';
$GLOBALS['__l10n']['Last page'] = '';
$GLOBALS['__l10n']['Page %s / %s'] = '';
$GLOBALS['__l10n']['Direct access page %s'] = '';
$GLOBALS['__l10n']['&#171; prev.'] = '';
$GLOBALS['__l10n']['next &#187;'] = '';
$GLOBALS['__l10n']['No entry matches the filter'] = '';
$GLOBALS['__l10n']['No entry'] = '';
$GLOBALS['__l10n']['List of %s entries match the filter.'] = '';
$GLOBALS['__l10n']['Entries list'] = '';
$GLOBALS['__l10n']['Protected'] = '';
$GLOBALS['__l10n']['%d attachment'] = '';
$GLOBALS['__l10n']['%d attachments'] = '';
$GLOBALS['__l10n']['No comments or trackbacks matches the filter'] = '';
$GLOBALS['__l10n']['Comment or trackback matching the filter.'][0] = '';
$GLOBALS['__l10n']['Comment or trackback matching the filter.'][1] = '';
$GLOBALS['__l10n']['Type'] = '';
$GLOBALS['__l10n']['Entry'] = '';
$GLOBALS['__l10n']['Edit the %1$s from %2$s'] = '';
$GLOBALS['__l10n']['comment'] = '';
$GLOBALS['__l10n']['trackback'] = '';
$GLOBALS['__l10n']['Type and author'] = '';
$GLOBALS['__l10n']['No user matches the filter'] = '';
$GLOBALS['__l10n']['No user'] = '';
$GLOBALS['__l10n']['List of %s users match the filter.'] = '';
$GLOBALS['__l10n']['Users list'] = '';
$GLOBALS['__l10n']['admin'] = '';
$GLOBALS['__l10n']['superadmin'] = '';
$GLOBALS['__l10n']['ratio %.1f'] = '';
$GLOBALS['__l10n']['(%s)'] = '';
$GLOBALS['__l10n']['The \'public\' directory does not exist.'] = '';
$GLOBALS['__l10n']['The \'%s\' directory cannot be modified.'] = '';
$GLOBALS['__l10n']['At least one of the following functions is not available: imagecreatetruecolor, imagepng & imagecreatefrompng.'] = '';
$GLOBALS['__l10n']['Unable to create images.'] = '';
$GLOBALS['__l10n']['Invalid file type.'] = '';
$GLOBALS['__l10n']['An error occurred while writing the file.'] = '';
$GLOBALS['__l10n']['Uploaded image is not %s pixels wide.'] = '';
$GLOBALS['__l10n']['Database error'] = '';
$GLOBALS['__l10n']['There seems to be no Session table in your database. Is Dotclear completly installed?'] = '';
$GLOBALS['__l10n']['System settings'] = '';
$GLOBALS['__l10n']['Blog'] = '';
$GLOBALS['__l10n']['Plugins'] = '';
$GLOBALS['__l10n']['medium'] = '';
$GLOBALS['__l10n']['small'] = '';
$GLOBALS['__l10n']['thumbnail'] = '';
$GLOBALS['__l10n']['square'] = '';
$GLOBALS['__l10n']['Posts'] = '';
$GLOBALS['__l10n']['Pages'] = '';
$GLOBALS['__l10n']['administrator'] = '';
$GLOBALS['__l10n']['manage their own entries and comments'] = '';
$GLOBALS['__l10n']['publish entries and comments'] = '';
$GLOBALS['__l10n']['delete entries and comments'] = '';
$GLOBALS['__l10n']['manage all entries and comments'] = '';
$GLOBALS['__l10n']['manage categories'] = '';
$GLOBALS['__l10n']['manage their own media items'] = '';
$GLOBALS['__l10n']['manage all media items'] = '';
$GLOBALS['__l10n']['That user does not exist in the database.'] = '';
$GLOBALS['__l10n']['That key does not exist in the database.'] = '';
$GLOBALS['__l10n']['You are not allowed to add categories'] = '';
$GLOBALS['__l10n']['You are not allowed to update categories'] = '';
$GLOBALS['__l10n']['You are not allowed to delete categories'] = '';
$GLOBALS['__l10n']['This category is not empty.'] = '';
$GLOBALS['__l10n']['You are not allowed to reset categories order'] = '';
$GLOBALS['__l10n']['Empty category URL'] = '';
$GLOBALS['__l10n']['You must provide a category title'] = '';
$GLOBALS['__l10n']['You must provide a category URL'] = '';
$GLOBALS['__l10n']['You are not allowed to create an entry'] = '';
$GLOBALS['__l10n']['You are not allowed to update entries'] = '';
$GLOBALS['__l10n']['No such entry ID'] = '';
$GLOBALS['__l10n']['You are not allowed to edit this entry'] = '';
$GLOBALS['__l10n']['You are not allowed to change this entry status'] = '';
$GLOBALS['__l10n']['You are not allowed to change this entry category'] = '';
$GLOBALS['__l10n']['You are not allowed to change entries category'] = '';
$GLOBALS['__l10n']['You are not allowed to delete entries'] = '';
$GLOBALS['__l10n']['No entry title'] = '';
$GLOBALS['__l10n']['No entry content'] = '';
$GLOBALS['__l10n']['Notes'] = '';
$GLOBALS['__l10n']['Note'] = '';
$GLOBALS['__l10n']['Empty entry URL'] = '';
$GLOBALS['__l10n']['You are not allowed to update comments'] = '';
$GLOBALS['__l10n']['No such comment ID'] = '';
$GLOBALS['__l10n']['You are not allowed to update this comment'] = '';
$GLOBALS['__l10n']['You are not allowed to change this comment\'s status'] = '';
$GLOBALS['__l10n']['You are not allowed to delete comments'] = '';
$GLOBALS['__l10n']['You must provide a comment'] = '';
$GLOBALS['__l10n']['You must provide an author name'] = '';
$GLOBALS['__l10n']['Email address is not valid.'] = '';
$GLOBALS['__l10n']['online'] = '';
$GLOBALS['__l10n']['offline'] = '';
$GLOBALS['__l10n']['removed'] = '';
$GLOBALS['__l10n']['You are not an administrator'] = '';
$GLOBALS['__l10n']['Invalid user language code'] = '';
$GLOBALS['__l10n']['Blog ID must contain at least 2 characters using letters, numbers or symbols.'] = '';
$GLOBALS['__l10n']['No blog name'] = '';
$GLOBALS['__l10n']['No blog URL'] = '';
$GLOBALS['__l10n']['No log message'] = '';
$GLOBALS['__l10n']['unknown'] = '';
$GLOBALS['__l10n']['No blog defined.'] = '';
$GLOBALS['__l10n']['You are not a super administrator.'] = '';
$GLOBALS['__l10n']['Permission denied.'] = '';
$GLOBALS['__l10n']['You are not the file owner.'] = '';
$GLOBALS['__l10n']['This file is not allowed.'] = '';
$GLOBALS['__l10n']['New file already exists.'] = '';
$GLOBALS['__l10n']['File does not exist in the database.'] = '';
$GLOBALS['__l10n']['Extract destination directory %s already exists.'] = '';
$GLOBALS['__l10n']['Embedded Audio Player'] = '';
$GLOBALS['__l10n']['Embedded Video Player'] = '';
$GLOBALS['__l10n']['Module "%s" has type "%s" that mismatch required module type "%s".'] = '';
$GLOBALS['__l10n']['Module "%s" is installed twice in "%s" and "%s".'] = '';
$GLOBALS['__l10n']['Empty module zip file.'] = '';
$GLOBALS['__l10n']['The zip file does not appear to be a valid Dotclear module.'] = '';
$GLOBALS['__l10n']['An error occurred during module deletion.'] = '';
$GLOBALS['__l10n']['Unable to upgrade "%s". (older or same version)'] = '';
$GLOBALS['__l10n']['Unable to read new _define.php file'] = '';
$GLOBALS['__l10n']['No such module.'] = '';
$GLOBALS['__l10n']['Cannot remove module files'] = '';
$GLOBALS['__l10n']['Cannot deactivate plugin.'] = '';
$GLOBALS['__l10n']['Cannot activate plugin.'] = '';
$GLOBALS['__l10n']['Invalid setting dcNamespace: %s'] = '';
$GLOBALS['__l10n']['Unable to retrieve settings:'] = '';
$GLOBALS['__l10n']['%s is not a valid setting id'] = '';
$GLOBALS['__l10n']['No namespace specified'] = '';
$GLOBALS['__l10n']['Unable to retrieve workspaces:'] = '';
$GLOBALS['__l10n']['Unable to retrieve namespaces:'] = '';
$GLOBALS['__l10n']['Invalid setting namespace: %s'] = '';
$GLOBALS['__l10n']['Failed to read data feed'] = '';
$GLOBALS['__l10n']['Wrong data feed'] = '';
$GLOBALS['__l10n']['An error occurred while downloading the file.'] = '';
$GLOBALS['__l10n']['%s has still been pinged'] = '';
$GLOBALS['__l10n']['Unable to ping URL'] = '';
$GLOBALS['__l10n']['%s is not a ping URL'] = '';
$GLOBALS['__l10n']['%s, ping error:'] = '';
$GLOBALS['__l10n']['Any chance you ping one of my contents? No? Really?'] = '';
$GLOBALS['__l10n']['Sorry but you can not ping this type of content.'] = '';
$GLOBALS['__l10n']['Oops. Kinda "not found" stuff. Please check the target URL twice.'] = '';
$GLOBALS['__l10n']['Sorry, dude. This entry does not accept pingback at the moment.'] = '';
$GLOBALS['__l10n']['Don\'t repeat yourself, please.'] = '';
$GLOBALS['__l10n']['Your source URL does not look like a supported content type. Sorry. Bye, bye!'] = '';
$GLOBALS['__l10n']['Where\'s your title?'] = '';
$GLOBALS['__l10n']['Sorry, an internal problem has occured.'] = '';
$GLOBALS['__l10n']['Thanks, mate. It was a pleasure.'] = '';
$GLOBALS['__l10n']['Digests file not found.'] = '';
$GLOBALS['__l10n']['No file to download'] = '';
$GLOBALS['__l10n']['Root directory is not writable.'] = '';
$GLOBALS['__l10n']['An error occurred while downloading archive.'] = '';
$GLOBALS['__l10n']['Archive not found.'] = '';
$GLOBALS['__l10n']['Unable to read current digests file.'] = '';
$GLOBALS['__l10n']['Downloaded file does not seem to be a valid archive.'] = '';
$GLOBALS['__l10n']['Incomplete archive.'] = '';
$GLOBALS['__l10n']['Unable to read digests file.'] = '';
$GLOBALS['__l10n']['Invalid digests file.'] = '';
$GLOBALS['__l10n']['Invalid dcWorkspace: %s'] = '';
$GLOBALS['__l10n']['Unable to retrieve prefs:'] = '';
$GLOBALS['__l10n']['%s is not a valid pref id'] = '';
$GLOBALS['__l10n']['No workspace specified'] = '';
$GLOBALS['__l10n']['No valid source URL provided? Try again!'] = '';
$GLOBALS['__l10n']['No valid target URL provided? Try again!'] = '';
$GLOBALS['__l10n']['LOL!'] = '';
$GLOBALS['__l10n']['SQLite Database Schema cannot be upgraded.'] = '';
$GLOBALS['__l10n']['Something went wrong with auto upgrade:'] = '';
$GLOBALS['__l10n']['Unable to open directory.'] = '';
$GLOBALS['__l10n']['Unable to create directory.'] = '';
$GLOBALS['__l10n']['File is not writable.'] = '';
$GLOBALS['__l10n']['Unable to open file.'] = '';
$GLOBALS['__l10n']['Not an uploaded file.'] = '';
$GLOBALS['__l10n']['The uploaded file exceeds the maximum file size allowed.'] = '';
$GLOBALS['__l10n']['The uploaded file was only partially uploaded.'] = '';
$GLOBALS['__l10n']['No file was uploaded.'] = '';
$GLOBALS['__l10n']['Missing a temporary folder.'] = '';
$GLOBALS['__l10n']['Failed to write file to disk.'] = '';
$GLOBALS['__l10n']['A PHP extension stopped the file upload.'] = '';
$GLOBALS['__l10n']['%s is not a directory.'] = '';
$GLOBALS['__l10n']['Bad range'] = '';
$GLOBALS['__l10n']['Invalid range'] = '';
$GLOBALS['__l10n']['Invalid line number'] = '';
$GLOBALS['__l10n']['Chunk is out of range'] = '';
$GLOBALS['__l10n']['Bad context'] = '';
$GLOBALS['__l10n']['Bad context (in deletion)'] = '';
$GLOBALS['__l10n']['Invalid diff format'] = '';
$GLOBALS['__l10n']['Uploading this file is not allowed.'] = '';
$GLOBALS['__l10n']['Destination directory is not in jail.'] = '';
$GLOBALS['__l10n']['File already exists.'] = '';
$GLOBALS['__l10n']['Cannot write in this directory.'] = '';
$GLOBALS['__l10n']['Source file does not exist.'] = '';
$GLOBALS['__l10n']['File is not in jail.'] = '';
$GLOBALS['__l10n']['Destination directory is not writable.'] = '';
$GLOBALS['__l10n']['Unable to rename file.'] = '';
$GLOBALS['__l10n']['File cannot be removed.'] = '';
$GLOBALS['__l10n']['Directory is not in jail.'] = '';
$GLOBALS['__l10n']['Directory cannot be removed.'] = '';
$GLOBALS['__l10n']['Not enough memory to open image.'] = '';
$GLOBALS['__l10n']['Did not find closing tag for block <tpl:%s>. Content has been ignored.'] = '';
$GLOBALS['__l10n']['Unexpected closing tag </tpl:%s> found.'] = '';
$GLOBALS['__l10n']['WARNING: the following errors have been found while parsing template file :'] = '';
$GLOBALS['__l10n']['singular'][0] = '';
$GLOBALS['__l10n']['singular'][1] = '';
$GLOBALS['__l10n']['File %s is not compressed in the zip.'] = '';
$GLOBALS['__l10n']['Trying to unzip a folder name %s'] = '';
$GLOBALS['__l10n']['Unable to write destination file.'] = '';
$GLOBALS['__l10n']['Unable to write in target directory, permission denied.'] = '';
$GLOBALS['__l10n']['Not enough memory to open file.'] = '';
$GLOBALS['__l10n']['File does not exist'] = '';
$GLOBALS['__l10n']['Cannot read file'] = '';
$GLOBALS['__l10n']['Directory does not exist'] = '';
$GLOBALS['__l10n']['Cannot read directory'] = '';
$GLOBALS['__l10n']['Site temporarily unavailable'] = '';
$GLOBALS['__l10n']['<p>We apologize for this temporary unavailability.<br />Thank you for your understanding.</p>'] = '';
$GLOBALS['__l10n']['Unable to connect to database'] = '';
$GLOBALS['__l10n']['<p>This either means that the username and password information in your <strong>config.php</strong> file is incorrect or we can\'t contact the database server at "<em>%s</em>". This could mean your host\'s database server is down.</p> <ul><li>Are you sure you have the correct username and password?</li><li>Are you sure that you have typed the correct hostname?</li><li>Are you sure that the database server is running?</li></ul><p>If you\'re unsure what these terms mean you should probably contact your host. If you still need help you can always visit the <a href="http://forum.dotclear.net/">Dotclear Support Forums</a>.</p>'] = '';
$GLOBALS['__l10n']['The following error was encountered while trying to read the database:'] = '';
